@@ -127,7 +127,7 @@ void Request::setAccessToken(const QString &token) {
     
     if (token != d->accessToken) {
         d->accessToken = token;
-        emit accessTokenChanged();
+        emit accessTokenChanged(token);
     }
 #ifdef QVIMEO_DEBUG
     qDebug() << "QVimeo::Request::setAccessToken" << token;
@@ -556,11 +556,6 @@ void Request::post(bool authRequired) {
         return;
     }
     
-    if (d->data.isNull()) {
-        qDebug() << "QVimeo::Request::post(): data is empty";
-        return;
-    }
-    
     d->redirects = 0;
     d->setOperation(PostOperation);
     
@@ -570,10 +565,12 @@ void Request::post(bool authRequired) {
     switch (d->data.type()) {
     case QVariant::String:
     case QVariant::ByteArray:
+    case QVariant::Invalid:
         data = d->data.toByteArray();
         break;
     default:
         data = QtJson::Json::serialize(d->data, ok);
+        break;
     }
 #ifdef QVIMEO_DEBUG
     qDebug() << "QVimeo::Request::post" << d->url << data;
@@ -606,11 +603,6 @@ void Request::put(bool authRequired) {
         return;
     }
     
-    if (d->data.isNull()) {
-        qDebug() << "QVimeo::Request::put(): data is empty";
-        return;
-    }
-    
     d->redirects = 0;
     d->setOperation(PutOperation);
     
@@ -620,10 +612,12 @@ void Request::put(bool authRequired) {
     switch (d->data.type()) {
     case QVariant::String:
     case QVariant::ByteArray:
+    case QVariant::Invalid:
         data = d->data.toByteArray();
         break;
     default:
         data = QtJson::Json::serialize(d->data, ok);
+        break;
     }
 #ifdef QVIMEO_DEBUG
     qDebug() << "QVimeo::Request::put" << d->url << data;
@@ -656,11 +650,6 @@ void Request::patch(bool authRequired) {
         return;
     }
     
-    if (d->data.isNull()) {
-        qDebug() << "QVimeo::Request::patch(): data is empty";
-        return;
-    }
-    
     d->redirects = 0;
     d->setOperation(PatchOperation);    
     
@@ -670,10 +659,12 @@ void Request::patch(bool authRequired) {
     switch (d->data.type()) {
     case QVariant::String:
     case QVariant::ByteArray:
+    case QVariant::Invalid:
         data = d->data.toByteArray();
         break;
     default:
         data = QtJson::Json::serialize(d->data, ok);
+        break;
     }
 #ifdef QVIMEO_DEBUG
     qDebug() << "QVimeo::Request::patch" << d->url << data;
@@ -789,7 +780,7 @@ void RequestPrivate::setStatus(Request::Status s) {
     if (s != status) {
         Q_Q(Request);
         status = s;
-        emit q->statusChanged();
+        emit q->statusChanged(s);
     }
 #ifdef QVIMEO_DEBUG
     qDebug() << "QVimeo::RequestPrivate::setStatus " << Request::Status(s);
@@ -877,7 +868,10 @@ void RequestPrivate::_q_onReplyFinished() {
         }
     
         if (!redirect.isEmpty()) {
+            reply->deleteLater();
+            reply = 0;
             followRedirect(redirect);
+            return;
         }
     }
     
@@ -885,7 +879,12 @@ void RequestPrivate::_q_onReplyFinished() {
     QString response(reply->readAll());
     setResult(response.isEmpty() ? response : QtJson::Json::parse(response, ok));
     
-    switch (reply->error()) {
+    QNetworkReply::NetworkError e = reply->error();
+    QString es = reply->errorString();
+    reply->deleteLater();
+    reply = 0;
+    
+    switch (e) {
     case QNetworkReply::NoError:
         break;
     case QNetworkReply::OperationCanceledError:
@@ -896,8 +895,8 @@ void RequestPrivate::_q_onReplyFinished() {
         return;
     default:
         setStatus(Request::Failed);
-        setError(Request::Error(reply->error()));
-        setErrorString(reply->errorString());
+        setError(Request::Error(e));
+        setErrorString(es);
         emit q->finished();
         return;
     }
@@ -912,7 +911,7 @@ void RequestPrivate::_q_onReplyFinished() {
         setError(Request::ParseError);
         setErrorString(Request::tr("Unable to parse response"));
     }
-    
+        
     emit q->finished();
 }
 
